drama.shaders = {};
drama.shaders["brightness"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float brightness;\n\nvoid main(void)\n{\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float a = front.a;\n	\n	if (a != 0.0)\n		front.rgb /= front.a;\n	\n	front.rgb += (brightness - 1.0);\n	\n	front.rgb *= a;\n	gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["brightness",0,1]]
};

drama.shaders["cga"] = {
	src: "#ifdef GL_FRAGMENT_PRECISION_HIGH\n#define highmedp highp\n#else\n#define highmedp mediump\n#endif\n\nvarying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\n\nvoid main(void)\n{\n	highmedp vec2 sampleDivisor = vec2(1.0 / 200.0, 1.0 / 320.0);\n\n	highmedp vec2 samplePos = vTex - mod(vTex, sampleDivisor);\n	highmedp vec4 color = texture2D(samplerFront, samplePos);\n\n	mediump vec4 colorCyan = vec4(85.0 / 255.0, 1.0, 1.0, 1.0);\n	mediump vec4 colorMagenta = vec4(1.0, 85.0 / 255.0, 1.0, 1.0);\n	mediump vec4 colorWhite = vec4(1.0, 1.0, 1.0, 1.0);\n	mediump vec4 colorBlack = vec4(0.0, 0.0, 0.0, 1.0);\n\n	mediump vec4 endColor;\n	highmedp float blackDistance = distance(color, colorBlack);\n	highmedp float whiteDistance = distance(color, colorWhite);\n	highmedp float magentaDistance = distance(color, colorMagenta);\n	highmedp float cyanDistance = distance(color, colorCyan);\n\n	mediump vec4 finalColor;\n\n	highmedp float colorDistance = min(magentaDistance, cyanDistance);\n	colorDistance = min(colorDistance, whiteDistance);\n	colorDistance = min(colorDistance, blackDistance); \n\n	if (colorDistance == blackDistance)\n		finalColor = colorBlack;\n	else if (colorDistance == whiteDistance)\n		finalColor = colorWhite;\n	else if (colorDistance == cyanDistance)\n		finalColor = colorCyan;\n	else\n		finalColor = colorMagenta;\n	\n	finalColor.rgb *= color.a;\n	finalColor.a = color.a;\n	gl_FragColor = finalColor;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: []
};

drama.shaders["grayscale"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float intensity;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);	lowp float gray = front.r * 0.299 + front.g * 0.587 + front.b * 0.114;	gl_FragColor = mix(front, vec4(gray, gray, gray, front.a), intensity);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1]]
};

drama.shaders["inverse"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float intensity;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);	lowp vec3 inverse = vec3(front.a - front.rgb);	gl_FragColor = vec4(mix(front.rgb, inverse, intensity), front.a);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1]]
};

drama.shaders["noise"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump float seconds;\nuniform lowp float intensity;\nuniform lowp float noiseColor;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float a = front.a;\n	\n	if (a != 0.0)\n		front.rgb /= a;\n	\n	mediump float seconds_mod = mod(seconds, 10.0);	mediump vec3 noise = vec3(fract(sin(dot(vTex.xy, vec2(12.9898,78.233)) + seconds_mod) * 43758.5453),\n							  fract(sin(dot(vTex.yx, vec2(12.9898,-78.233)) + seconds_mod) * 43758.5453),\n							  fract(sin(dot(vTex.xy, vec2(-12.9898,-78.233)) + seconds_mod) * 43758.5453));\n	noise = mix(vec3(noise.r), noise, noiseColor);\n	front.rgb += (noise * intensity) - (intensity / 2.0);\n	front.rgb *= a;\n	\n	gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1],["noiseColor",0,1]]
};

drama.shaders["tint"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp vec3 tintColor;\n\nvoid main(void)\n{\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	\n	gl_FragColor = front * vec4(tintColor.r, tintColor.g, tintColor.b, 1.0);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["tintColor",0,2]]
};

drama.shaders["toon"] = {
	src: "#ifdef GL_FRAGMENT_PRECISION_HIGH\n#define highmedp highp\n#else\n#define highmedp mediump\n#endif\n\nvarying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\n\nprecision highmedp float;\nuniform highmedp vec2 pixelSize;\nuniform highmedp float threshold;\nuniform highmedp float quantizationLevels;\n\nvoid main(void)\n{\n	vec4 front = texture2D(samplerFront, vTex);\n\n	float dx = pixelSize.x;\n	float dy = pixelSize.y;\n	\n    float bottomLeftIntensity = texture2D(samplerFront, vTex + vec2(-dx, dy)).r;\n    float topRightIntensity = texture2D(samplerFront, vTex + vec2(dx, -dy)).r;\n    float topLeftIntensity = texture2D(samplerFront, vTex + vec2(-dx, -dy)).r;\n    float bottomRightIntensity = texture2D(samplerFront, vTex + vec2(dx, dy)).r;\n    float leftIntensity = texture2D(samplerFront, vTex + vec2(-dx, 0.0)).r;\n    float rightIntensity = texture2D(samplerFront, vTex + vec2(dx, 0.0)).r;\n    float bottomIntensity = texture2D(samplerFront, vTex + vec2(0.0, dy)).r;\n    float topIntensity = texture2D(samplerFront, vTex + vec2(0.0, -dy)).r;\n	float h = -topLeftIntensity - 2.0 * topIntensity - topRightIntensity + bottomLeftIntensity + 2.0 * bottomIntensity + bottomRightIntensity;\n	float v = -bottomLeftIntensity - 2.0 * leftIntensity - topLeftIntensity + bottomRightIntensity + 2.0 * rightIntensity + topRightIntensity;\n\n	float mag = length(vec2(h, v));\n\n	vec3 posterized = floor((front.rgb * (quantizationLevels-1.0)) + 0.5) / (quantizationLevels-1.0);\n\n	float thresholdTest = 1.0 - step(threshold, mag);\n\n	gl_FragColor = vec4(posterized * thresholdTest, front.a);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["threshold",0,1],["quantizationLevels",0,0]]
};

drama.shaders["vibrance"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float vibrance;\n\nvoid main(void)\n{\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float average = front.r / 3.0 + front.g / 3.0 + front.b / 3.0;\n	lowp float max_ = max(front.r, max(front.g, front.b));\n	lowp float amount = (max_ - average) * (vibrance * -3.0);\n	front.rgb = mix(front.rgb, vec3(max_), amount);\n	gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["vibrance",0,1]]
};

drama.shaders["vignette"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\n\nuniform mediump float vignetteStart;\nuniform mediump float vignetteEnd;\n\nvoid main(void)\n{	\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float a = front.a;\n	\n	if (a != 0.0)\n		front.rgb /= a;\n	\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n    lowp float d = distance(tex, vec2(0.5, 0.5));\n    front.rgb *= smoothstep(vignetteEnd, vignetteStart, d);\n	front.rgb *= a;\n	\n    gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["vignetteStart",0,1],["vignetteEnd",0,1]]
};

drama.shaders["warpobject"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform mediump vec2 srcOriginStart;\nuniform mediump vec2 srcOriginEnd;\nuniform mediump float seconds;\nuniform mediump vec2 pixelSize;\nuniform mediump float layerScale;\n\nuniform mediump float freqX;\nuniform mediump float freqY;\nuniform mediump float ampX;\nuniform mediump float ampY;\nuniform mediump float speedX;\nuniform mediump float speedY;\n\nvoid main(void)\n{\n	mediump float _2pi = 2.0 * 3.14159265359;	mediump vec2 srcOriginSize = srcOriginEnd - srcOriginStart;\n	mediump vec2 n = ((vTex - srcOriginStart) / srcOriginSize);	mediump vec2 p = vTex;\n	p.x += cos(n.y * _2pi * freqY + seconds * speedY * _2pi) * ampY * pixelSize.x * layerScale;\n	p.y += sin(n.x * _2pi * freqX + seconds * speedX * _2pi) * ampX * pixelSize.y * layerScale;	p = clamp(p, min(srcStart, srcEnd), max(srcStart, srcEnd));\n	\n	gl_FragColor = texture2D(samplerFront, p);\n}\n",
	extendBoxHorizontal: 30,
	extendBoxVertical: 30,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: true,
	parameters: [["freqX",0,0],["freqY",0,0],["ampX",0,0],["ampY",0,0],["speedX",0,0],["speedY",0,0]]
};

drama.shaders["water"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\n\nprecision mediump float;\nuniform float seconds;\nuniform mediump vec2 pixelSize;\n\nconst float PI = 3.1415926535897932;uniform float speed;\nuniform float speed_x;\nuniform float speed_y;uniform float intensity;\nconst float steps = 8.0;\nuniform float frequency;\nuniform float angle;uniform float delta;\nuniform float intence;\nuniform float emboss;\n\nfloat col(vec2 coord)\n{\n	float delta_theta = 2.0 * PI / angle;\n	float col = 0.0;\n	float theta = 0.0;\n	for (float i = 0.0; i < steps; i++)\n	{\n		vec2 adjc = coord;\n		theta = delta_theta*i;\n		adjc.x += cos(theta)*seconds*speed + seconds * speed_x;\n		adjc.y -= sin(theta)*seconds*speed - seconds * speed_y;\n		col = col + cos( (adjc.x*cos(theta) - adjc.y*sin(theta))*frequency)*intensity;\n	}\n\n	return cos(col);\n}\n\nvoid main(void)\n{\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n	\n	vec2 p = tex, c1 = p, c2 = p;\n	float cc1 = col(c1);\n\n	c2.x += (1.0 / pixelSize.x) / delta;\n	float dx = emboss*(cc1-col(c2))/delta;\n\n	c2.x = p.x;\n	c2.y += (1.0 / pixelSize.y) / delta;\n	float dy = emboss*(cc1-col(c2))/delta;\n\n	c1.x += dx;\n	c1.y = -(c1.y+dy);\n\n	float alpha = 1.+dot(dx,dy)*intence;\n	c1.y = -c1.y;\n	c1 = clamp(c1, 0.0, 1.0);\n	gl_FragColor = texture2D(samplerFront, mix(srcStart, srcEnd, c1)) * alpha;\n}\n",
	extendBoxHorizontal: 40,
	extendBoxVertical: 40,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: true,
	parameters: [["speed",0,1],["speed_x",0,1],["speed_y",0,1],["intensity",0,0],["frequency",0,0],["angle",0,0],["delta",0,0],["intence",0,0],["emboss",0,1]]
};
